/* small helper to get the current subarch's loaddr */

#include <stdio.h>
#include <stdint.h>

#include "subarch.h"

int main()
{
	printf("0x%lx\n", kernel_load[SUBARCH].base 
				+ kernel_load[SUBARCH].reserved);
	return(0);
}
